using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Grouping;

namespace F83649
{
    public partial class Form1 : Form
    {
        private DataTable productTable, detailTable;
        private GridRelationDescriptor parentToChildRelationDescriptor;
        public Form1()
        {
            InitializeComponent();

            productTable = GetProductTable();
            detailTable = GetDetailsTable();

            // Manually specify relations in grouping engine. The DataSet does not need to have any DataRelations.
            // This is the same approach that should be used if you want to set up relation ships
            // between independent IList.
            parentToChildRelationDescriptor = new GridRelationDescriptor();
            parentToChildRelationDescriptor.ChildTableName = "DetailTable";    // same as SourceListSetEntry.Name for childTable (see below)
            parentToChildRelationDescriptor.RelationKind = RelationKind.RelatedMasterDetails;
            parentToChildRelationDescriptor.RelationKeys.Add("productID", "ProductID");

            // Add relation to ParentTable 
            gridGroupingControl1.TableDescriptor.Relations.Add(parentToChildRelationDescriptor);

            this.gridGroupingControl1.BeginUpdate();
            // Register any DataTable/IList with SourceListSet, so that RelationDescriptor can resolve the name
            this.gridGroupingControl1.Engine.SourceListSet.Add("ProductTable", productTable);
            this.gridGroupingControl1.Engine.SourceListSet.Add("DetailTable", detailTable);

            this.gridGroupingControl1.DataSource = productTable;
            this.gridGroupingControl1.EndUpdate(true);

        }

        # region DataTables

        private int productRowCount = 5;
        private int detailRowCount = 20;
        private DataTable GetProductTable()
        {
            DataTable dt = new DataTable("Products");


            dt.Columns.Add(new DataColumn("productID")); //lower case p
            dt.Columns.Add(new DataColumn("ProductName"));
            dt.Columns.Add(new DataColumn("ProductDesc"));

            for (int i = 0; i < productRowCount; i++)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i;
                dr[1] = string.Format("productname{0}", i);
                dr[2] = string.Format("productdesc{0}", i);
                dt.Rows.Add(dr);
            }

            return dt;
        }

        private DataTable GetDetailsTable()
        {
            DataTable dt = new DataTable("Details");

            dt.Columns.Add(new DataColumn("DetailID")); //lower case c
            dt.Columns.Add(new DataColumn("Name"));
            dt.Columns.Add(new DataColumn("ProductID")); //upper case P

            for (int i = 0; i < detailRowCount; i++)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i.ToString();
                dr[1] = string.Format("Detail{0}", i);
                dr[2] = (i % productRowCount).ToString();
                dt.Rows.Add(dr);
            }

            return dt;
        }
        #endregion

        private void button1_Click(object sender, EventArgs e)
        {
            this.gridGroupingControl1.DataSource = null;
            this.gridGroupingControl1.TableDescriptor.Relations.Add(parentToChildRelationDescriptor);
            this.gridGroupingControl1.Engine.SourceListSet.Add("ProductTable", productTable);
            this.gridGroupingControl1.Engine.SourceListSet.Add("DetailTable", detailTable);
            this.gridGroupingControl1.BeginUpdate();
            this.gridGroupingControl1.DataSource = productTable;
            this.gridGroupingControl1.EndUpdate(true);
        }
    }
}